@@ -228,27 +228,6 @@ class FlaskTest(BaseTest):
         _, _, app_ndebug = self.make_client_and_raven(debug=False)
         self.assertTrue(app_ndebug.extensions['sentry'].wrap_wsgi)
 
-    def test_error_handler_with_ignored_exception(self):
-        client, raven, _ = self.make_client_and_raven(ignore_exceptions=[NameError, ValueError])
-
-        response = client.get('/an-error/')
-        self.assertEquals(response.status_code, 500)
-        self.assertEquals(len(raven.events), 0)
-
-    def test_error_handler_with_exception_not_ignored(self):
-        client, raven, _ = self.make_client_and_raven(ignore_exceptions=[NameError, KeyError])
-
-        response = client.get('/an-error/')
-        self.assertEquals(response.status_code, 500)
-        self.assertEquals(len(raven.events), 1)
-
-    def test_error_handler_with_empty_ignore_exceptions_list(self):
-        client, raven, _ = self.make_client_and_raven(ignore_exceptions=[])
-
-        response = client.get('/an-error/')
-        self.assertEquals(response.status_code, 500)
-        self.assertEquals(len(raven.events), 1)
-
     def test_captureException_sets_last_event_id(self):
         with self.app.test_request_context('/'):
             try:
@@ -286,9 +265,13 @@ class FlaskTest(BaseTest):
     def test_check_client_type(self):
         self.assertRaises(TypeError, lambda _: Sentry(self.app, "oops, I'm putting my DSN instead"))
 
+    def test_uses_dsn(self):
+        app = Flask(__name__)
+        sentry = Sentry(app, dsn='http://public:secret@example.com/1')
+        assert sentry.client.remote.base_url == 'http://example.com'
+
 
 class FlaskLoginTest(BaseTest):
-
     @fixture
     def app(self):
         return create_app(SENTRY_USER_ATTRS=['name'])
